<section>
    <div>Hello <span id='name'>John Doe</span>!</div>

    <div class="append-name">Hello, </div>
    <div class="prepend-name">, hello!</div>
    <div class="replace-name">Hello, <name/></div>
    <div id="append-replace-name">Hello, <name>Mr </name>!</div>
    <div id="prepend-replace-name">Mr <name>, hello!</name></div>

    <div id="code"></div>

    <dl id='contact'>
        <dt>Phone</dt>
        <dd class='phone'>(xxx) xxx-xxxx</dd>
        <dt>Email</dt>
        <dd class='email'>aaa@email.com</dd>
    </dl>

    <dl id='contact2'>
        <dt>Phone</dt>
        <dd class='phone'>(xxx) xxx-xxxx</dd>
        <dt>Email</dt>
        <dd class='email'>aaa@email.com</dd>
    </dl>

    <div>
        <article>
            <span class="position"></span>
            <a class="post-title post-link">Post Title</a>
            <div class="post-content">Lorem ipsum dolor sit.</div>

            <ul>
                <li class="tag"><a/></li>
            </ul>
        </article>
    </div>

</section>
