<!DOCTYPE html>
<html>
<head>
    <title>Hello Plift</title>
</head>
<body>
    <x-include template="layout/header" />

    <div id="content"></div>

    <div data-plift-include="layout/footer"></div>

    <if class="false"><x-include template="section" if="include_section" /></if>
    <if class="true"><x-include template="section" if="include_all" /></if>
    <unless class="false"><x-include template="section" unless="skip_all" /></unless>
    <unless class="true"><x-include template="section" unless="skip_section" /></unless>

</body>
</html>
