<!DOCTYPE html>
<html>
<head>
    <title>Hello Plift</title>
</head>
<body>
    <x-include template="../layout/header" />

    <div id="content"></div>

    <div data-plift-include="../layout/footer"></div>

</body>
</html>
